<?php

$services = array(
    "title" => "Services",
    "title_singular" => "Services",
    "slug"  => "scc-services"
);
$scc_services_taxonomy = "scc-services";

add_action('init', 'register_cpt_scc_services');
add_action('admin_menu', 'scc_services_menu');
add_action('admin_init', 'scc_services_init');
add_action('save_post_scc-services', 'scc_services_save_custom_fields');

function register_cpt_scc_services(){
    global $services;
    global $scc_services_taxonomy;

    $labels = array(
        'name' => _x( $services['title'], $services['slug'] ),
        'singular_name' => _x( $services['title_singular'], $services['slug']),
        'add_new' => _x( 'Add New', $services['slug'] ),
        'add_new_item' => _x( 'Add New ' . $services['title_singular'], $services['slug'] ),
        'edit_item' => _x( 'Edit ' . $services['title_singular'], $services['slug'] ),
        'new_item' => _x( 'New ' . $services['title_singular'], $services['slug'] ),
        'view_item' => _x( 'View ' . $services['title_singular'], $services['slug'] ),
        'search_items' => _x( 'Search ' . $services['title'], $services['slug'] ),
        'not_found' => _x( 'No ' . $services['title'] . ' found', $services['slug'] ),
        'not_found_in_trash' => _x( 'No ' . $services['title'] . ' found in Trash', $services['slug'] ),
        'parent_item_colon' => _x( 'Parent ' . $services['title'], $services['slug'] ),
        'menu_name' => _x( $services['title'], $services['slug'] ),
    );

    $args = array(
        'labels'              => $labels,
        'hierarchical'        => false,
        'description'         => $services['title'] . ' Articles',
        'supports'            => array( 'title', 'editor', 'thumbnail' ),
        'taxonomies'          => array( $scc_services_taxonomy ),
        'public'              => true,
        'show_ui'             => true,
        'show_in_menu'        => true,
        'show_in_nav_menus'   => true,
        'menu_position'       => 8,
        'menu_icon'           => 'dashicons-index-card',
        'publicly_queryable'  => true,
        'exclude_from_search' => false,
        'rewrite'             => array( 'slug' => 'services', 'with_front' => false ),
        'has_archive'         => false,
        'query_var'           => true,
        'can_export'          => true,
        'capability_type'     => 'post'
    );

    /*register_taxonomy(
        $scc_services_taxonomy,
        $services['slug'],
        array(
            'label' => __( 'Testimonial' ),
            'hierarchical' => true,
            'rewrite' => array("slug" => 'scc-testimonial'),
            'query_var' => true,
            'has_archive' => true,
            'show_admin_column' => true
        )
    );
    flush_rewrite_rules();*/

    register_post_type( $services['slug'], $args );
}

function scc_services_menu(){
    /*wp_enqueue_script('scc-services-js',get_template_directory_uri() . '/js/admin/admin-scc-services.js',array('jquery'),'1.0',true);
    wp_enqueue_script('spectrum',get_template_directory_uri() . '/js/admin/spectrum.js',array('jquery'),'1.0',true);
    wp_enqueue_style('spectrum',get_template_directory_uri() . '/css/spectrum.css');*/
}

function scc_services_init(){
    scc_services_create_custom_fields();
}

/* =================================
 * ***** CUSTOM FIELDS ******
 * =================================
 */

//change "title" post display text so it indicates you need to enter a name
add_filter('gettext','scc_services_custom_enter_title');//change post title help-display text
function scc_services_custom_enter_title( $input ) {

    global $post_type;
    global $services;
    global $scc_services_taxonomy;

    $display_text = "Enter Service Name";

    if( is_admin() && 'Enter title here' == $input && ($post_type == $scc_services_taxonomy) ){
        if($services['slug'] == $post_type){
            return $display_text;
        }
    }

    return $input;
}

function scc_services_create_custom_fields(){
    global $services;

    //add stuff here
    add_meta_box('Service Icon', 'Service Icon', 'scc_services_icon_custom_fields', $services['slug'], 'side', 'default');
//    add_meta_box('Medium Description', 'Medium Description', 'scc_services_medium_description_custom_fields', $services['slug'], 'normal', 'high');
}

function scc_services_icon_custom_fields(){
    global $post;

    $custom = get_post_custom($post->ID);

    $service_icon = isset($custom['service_icon'][0]) ? $custom['service_icon'][0] : '';
    $service_color = isset($custom['service_color'][0]) ? $custom['service_color'][0] : '#888';

    ?>
    <p><strong style="margin-right: 1em;">Color</strong><input type="text" name="service_color" value="<?php echo $service_color;?>" class="spectrum-colorpicker"></p>

    <p><strong>Service Icon</strong></p>
    <div class="media-uploader scc-services-icon">
        <input class="media-uploader--file-url" name="service_icon" type="hidden"
               value="<?php echo $service_icon; ?>"/>
        <button class="button button-primary media-uploader--upload-button">Add file or Browse...</button>
    </div>
    <?php
}

function scc_services_medium_description_custom_fields(){
    global $post;

    $custom = get_post_custom($post->ID);
    $medium_description = isset($custom['medium_description'][0]) ? $custom['medium_description'][0] : '';

    wp_editor( $medium_description, 'medium_description', array(
        'wpautop'       => true,
        'media_buttons' => false,
        'textarea_name' => 'medium_description',
        'textarea_rows' => 10,
        'teeny'         => true
    ) );
}

function scc_services_save_custom_fields(){
    global $post;
	$post_type = get_post_type($post);

    if(isset($_POST['save']) || isset($_POST['publish']) && $post_type=="scc-services"){
        update_post_meta($post->ID, 'service_icon', $_POST['service_icon']);
        update_post_meta($post->ID, 'service_color', $_POST['service_color']);
//        update_post_meta($post->ID, 'medium_description', $_POST['medium_description']);
    }
}