<?php
class BlogPosts{
    private $posts = [];
    private $options = [];
    private $num_columns = 3;

    public function __construct($options=array())
    {
        if(!isset($options['id'])){ $options['id'] = ""; }
        if(!isset($options['limit'])){ $options['limit'] = -1; }
        if(!isset($options['category'])){ $options['category'] = ""; }
        if(!isset($options['classes'])){ $options['classes'] = ""; }
        if(!isset($options['excerpt_length']) || $options['excerpt_length']==""){ $options['excerpt_length'] = 30; }
        if(!isset($options['excerpt_more']) || $options['excerpt_more']==""){ $options['excerpt_more'] = "&hellip;"; }
        if(isset($options['columns'])){ $this->num_columns = $options['columns']; }

        $this->options = $options;

        $this->getPosts();
    }

    public function getPosts()
    {
        $this->posts = [];
        $qryArgs = array(
            "posts_per_page"    => $this->options['limit'],
            "order"    => "ASC"
        );

        //check if getting by category
        if($this->options['category']!=""){
            $qryArgs['category_name'] = $this->options['category'];
        }

        //Check if getting by IDs
        if($this->options['id']!=""){
            $ids = explode(',',$this->options['id']);
            $qryArgs['post__in'] = $ids;
        }

        $qryPosts = new WP_Query($qryArgs);

        if ($qryPosts->have_posts()):
            while ($qryPosts->have_posts()) : $qryPosts->the_post();
                global $post;
                setup_postdata($post);

                $id = get_the_ID();

                $post_image = wp_get_attachment_image_src( get_post_thumbnail_id($id), 'full' );
                $post_image = $post_image['0'];

                $post_thumb = wp_get_attachment_image_src( get_post_thumbnail_id($id), 'small' );
                $post_thumb = $post_thumb['0'];

                //Change excerpt "Read More" text
/*                add_filter('excerpt_length', function(){$this->excerpt_length($this->options['excerpt_length']);});
                add_filter('excerpt_more', function(){$this->excerpt_more($this->options['excerpt_more']);});*/

                $currItem = array(
                    "id" => $id,
                    "title" => get_the_title(),
                    "date" => get_the_date(),
                    "author" => get_the_author(),
                    "author_picture" => get_avatar_url( get_the_author_meta( 'ID' ), array(32) ),
                    "image" => $post_image,
                    "image_thumb" => $post_thumb,
                    "excerpt" => $this->create_excerpt($this->options['excerpt_length'],$this->options['excerpt_more']),
                    "content" => get_the_content(),
                    "link" => get_the_permalink()
                );
                array_push($this->posts,$currItem);
            endwhile;
            wp_reset_postdata();
        endif;
    }

    private function create_excerpt($length=30,$more='&hellip;') {
        $length = (int)$length;
        $limit = $length + 1;
        $excerpt = explode(' ', get_the_excerpt(), $limit);
        array_pop($excerpt);
        $excerpt = implode(" ",$excerpt).$more;
        return $excerpt;
    }
    
    public function blog_grid(){
        ?>
        <div class="blog-grid<?php if($this->options['classes']!=""){ echo " " . $this->options['classes']; }?>">
            <div class="grid">
                <div class="row">
                    <?php foreach($this->posts as $post): ?>
                        <div class="col<?php echo $this->num_columns;?>">
                            <a href="<?php echo $post['link'];?>">
                                <article class="post__card">
                                    <div class="post__card--image" style="background-image: url('<?php echo $post['image_thumb']; ?>')"></div>
                                    <div class="post__card--content">
                                        <h1><?php echo $post['title'];?></h1>
                                        <div class="post__card--date"><?php echo $post['date'];?></div>
                                        <div class="post__card--excerpt"><?php echo $post['excerpt'];?></div>
                                    </div>
                                </article>
                            </a>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
        <?php
    }
}