<?php
class HealthConditions
{
    private $healthConditions = [];
    private $postType = "scc-health-cond";
    private $options = [];
    private $num_columns = 4;

    public function __construct($options=array())
    {
        if(!isset($options['id'])){ $options['id'] = ""; }
        if(!isset($options['limit'])){ $options['limit'] = -1; }
        if(!isset($options['exclude'])){ $options['exclude'] = ""; }

        $this->options = $options;

        if($options['id']!=""){
            $this->options['id'] = explode(',',$options['id']);
        }

        if($options['exclude']!=""){
            $this->options['exclude'] = explode(',',$options['exclude']);
        }

        $this->getServices();
    }

    public function getServices()
    {
        $args = array(
            'post_type' => $this->postType,
            'orderby' => 'menu_order',
            'order' => 'ASC',
            'posts_per_page' => -1
        );

        if ($this->options['limit'] > 0) {
            $args['posts_per_page'] = intval($this->options['limit']);
        }

        $qryServices = new WP_Query($args);

        if ($qryServices->have_posts()):
            while ($qryServices->have_posts()) : $qryServices->the_post();
                global $post;

                $id = get_the_ID();

                if($this->options['exclude']!="" && in_array($id,$this->options['exclude'])){
                    continue;
                }

                if($this->options['id'] && !in_array($id,$this->options['id'])){
                    continue;
                }

                $customFields = get_post_custom($id);

                $image_full = wp_get_attachment_image_src( get_post_thumbnail_id($id), 'full' );
                $image_full = $image_full['0'];

                $image = wp_get_attachment_image_src( get_post_thumbnail_id($id), 'small' );
                $image = $image['0'];

                $content = apply_filters('the_content',get_the_content());
                $medium_description = apply_filters('the_content',$customFields['medium_description'][0]);

                $currItem = array(
                    "id"                 => $id,
                    "name"               => get_the_title(),
                    "content"            => $content,
                    "excerpt"            => get_the_excerpt(),
                    "image_full"         => $image_full,
                    "image"              => $image,
                    "slug"               => $post->post_name,
                    "link"               => get_the_permalink()
                );
                array_push($this->healthConditions,$currItem);
            endwhile;

        endif;
        /*$html = $this->generate_html();
        return $html;*/
    }

    public function generate_html($type="small"){
        $type = strtolower($type);
        
        $TYPES = array(
            "SMALL" => "small",
            "MEDIUM" => "medium",
            "FULL" => "full",
            "SINGLE" => "single"
        );
        
        if($type==$TYPES['SMALL'] || $type==$TYPES['FULL']) :
            ?><div class="health-conditions grid"><?php
                $count = 1;

            $link_condition = ((isset($this->options['external_links']) && $this->options['external_links']=="no") || $type==$TYPES['FULL']);

                foreach($this->healthConditions as $healthCondition):
                    $link = $healthCondition['link'];

                    //determine if small service cards will link to full single page, or to another location on the same page
                    if($link_condition){
                        $link = "#" . $healthCondition['slug'];
                    }

                    $stylesAry = array();
                    
                    if($healthCondition['image']){
                        array_push($stylesAry,'background-image: url(\'' . $healthCondition['image'] . '\')');
                    }
        
                    $styles = implode(';',$stylesAry);
        
                    //if remainder count/num_columns equals 1,put row div
                    if(($count % $this->num_columns)==1):?>
                        <div class="row">
                    <?php endif; ?>
                        <div class="col4">
                            <?php if($link !=""):?><a href="<?php echo $link;?>"><?php endif; ?>
                                <div class="health-condition">
                                    <div class="health-condition--image" style="<?php echo $styles; ?>"></div>
                                    <span class="health-condition--text"><?php echo $healthCondition['name']; ?></span>
                                </div>
                                <?php if($link !=""):?></a><?php endif; ?>
                        </div>
                    <?php
                    //if remainder count/num_columns equals 0, OR count = the last item in the loop, put end row div
                    if((($count % $this->num_columns)==0) || ($count==count($this->healthConditions))):?>
                        </div><!-- end .row -->
                    <?php endif;
                    $count++;
                endforeach;
            ?></div><?php //end .healthConditions
        endif;
    }
}
?>