<?php
class Services
{
	private $services = [];
	private $postType = "scc-services";
	private $options = [];
	private $num_columns = 3;

	public function __construct($options=array())
	{
		if(!isset($options['id'])){ $options['id'] = ""; }
		if(!isset($options['limit'])){ $options['limit'] = -1; }
		if(!isset($options['exclude'])){ $options['exclude'] = ""; }

		$this->options = $options;

		if($options['id']!=""){
			$this->options['id'] = explode(',',$options['id']);
		}

		if($options['exclude']!=""){
			$this->options['exclude'] = explode(',',$options['exclude']);
		}

		$this->getServices();
	}

	public function getServices()
	{
		$args = array(
			'post_type' => $this->postType,
			'orderby' => 'menu_order',
			'order' => 'ASC',
			'posts_per_page' => -1
		);

		if ($this->options['limit'] > 0) {
			$args['posts_per_page'] = intval($this->options['limit']);
		}

		$qryServices = new WP_Query($args);

		if ($qryServices->have_posts()):
			while ($qryServices->have_posts()) : $qryServices->the_post();
				global $post;

				$id = get_the_ID();

				if($this->options['exclude']!="" && in_array($id,$this->options['exclude'])){
					continue;
				}

				if($this->options['id'] && !in_array($id,$this->options['id'])){
					continue;
				}

				$customFields = get_post_custom($id);

				$image = wp_get_attachment_image_src( get_post_thumbnail_id($id), 'small' );
				$image = $image['0'];

				$content = apply_filters('the_content',get_the_content());

				$currItem = array(
					"id"                 => $id,
					"name"               => get_the_title(),
					"content"            => $content,
					"excerpt"            => get_the_excerpt(),
					"icon"               => $customFields['service_icon'][0],
					"image"              => $image,
					"slug"               => $post->post_name,
					"color"              => $customFields['service_color'][0],
					"link"               => get_the_permalink()
				);

				array_push($this->services,$currItem);
			endwhile;

		endif;
		/*$html = $this->generate_html();
		return $html;*/
	}

	public function generate_html($type="small"){
		$type = strtolower($type);

		$TYPES = array(
			"SMALL" => "small",
			"MEDIUM" => "medium",
			"FULL" => "full",
			"SINGLE" => "single"
		);

		if($type==$TYPES['SMALL'] || $type==$TYPES['FULL']) :
			?><div class="services grid"><?php
			$count = 1;

			$link_condition = ((isset($this->options['external_links']) && $this->options['external_links']=="no") || $type==$TYPES['FULL']);

			foreach($this->services as $service):
				$link = $service['link'];

				//determine if small service cards will link to full single page, or to another location on the same page
				if($link_condition){
					$link = 'services/' . $service['slug'];
				}

				$stylesAry = array();

				if($service['image']){
					array_push($stylesAry,'background-image: url(\'' . $service['image'] . '\')');
				}

				$styles = implode(';',$stylesAry);

				//if remainder count/num_columns equals 1,put row div
				if(($count % $this->num_columns)==1):?><div class="row"><?php endif; ?>
                <div class="col<?php echo $this->num_columns;?>">
                    <a href="<?php echo $link;?>">
                        <div class="service__small">
                            <div class="service__small--body">
                                <div class="service__small--header" style="<?php echo $styles;?>">
                                    <div class="service__small--header-overlay" style="background-color: <?php echo $service['color'];?>"></div>
                                    <div class="service__small--header-info">
										<?php if($service['icon']!=""): ?><img src="<?php echo $service['icon'];?>" alt="<?php echo $service['name'];?>" style="background-color: <?php echo $service['color'];?>"><?php endif;?>
                                        <h3><?php echo $service['name'];?></h3>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </a>
                </div>

				<?php
				//if remainder count/num_columns equals 0, OR count = the last item in the loop, put end row div
				if((($count % $this->num_columns)==0) || ($count==count($this->services))):?>
                    </div><!-- end .row -->
				<?php endif;
				$count++;
			endforeach;
			?></div><?php //end .services
		endif;

		if($type==$TYPES['MEDIUM'] || $type==$TYPES['FULL']) :
			?>
            <div class="services">
				<?php
				$count = 0;
				foreach($this->services as $service) :
					$themeSetup = array(
						"class" => 'theme0',
						"background_style" => "",
						"color_style" => "color: " . $service['color'],
						"button_theme" => "theme1",
						"button_style" => "background-color: " . $service['color'] . " !important; color: #fff !important;"
					);
					if($count % 2 == 0){
						$themeSetup['class'] = 'theme2';
						$themeSetup['background_style'] = 'background-color: ' . $service['color'];
						$themeSetup['color_style'] = '';
						$themeSetup['button_theme'] = 'theme0';
						$themeSetup['button_style'] = 'color: ' . $service['color'] . ' !important';
					}
					?>
                    <section class="section-plain <?php echo $themeSetup['class'];?>" style="<?php echo $themeSetup['background_style'];?>">
                        <div class="wrapper padding-default">
                            <div class="service__medium">
                                <h1 id="<?php echo $service['slug'];?>">
                                    <img src="<?php echo $service['icon'];?>" alt="Sound Corrections - <?php echo $service['name']; ?> service icon" style="background-color: <?php echo $service['color'];?>">
                                    <span style="<?php echo $themeSetup['color_style'];?>"><?php echo $service['name'];?></span>
                                </h1>
                                <div>
									<?php echo $service['excerpt']; ?>
                                    <div style="text-align: right">
                                        <a href="<?php echo $service['link'];?>"><button class="btn-main <?php echo $themeSetup['button_theme'];?>" style="<?php echo $themeSetup['button_style'];?>">Learn More</button></a>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </section>
					<?php
					$count++;
				endforeach; ?>
            </div>
		<?php
		endif;
	}
}
?>