<?php

require_once(get_template_directory() . '/lib/vars.php');
require_once(get_template_directory() . '/lib/reusables.php');

add_shortcode('section','scc_section_shortcode');
add_shortcode('cover_image','cover_image_main_shortcode');
add_shortcode('page_header','scc_section_header_shortcode');

//SHORTCODE: page_header
//DESC:      Places a page header across the top of the page with the title of the page, unless otherwise specified
function scc_section_header_shortcode($attr,$content=null){
    extract(shortcode_atts(
            array(
                'theme' => '1',
                'title' => get_the_title(),
            ),
            $attr,
            'scc_section_header')
    );

    $themeClass = "theme$theme";

    ob_start();
    include(SHORTCODE_TEMPLATE_FILES_URL . 'section-header.php');
    $sc = ob_get_contents();

    ob_end_clean();

    return $sc;
}

function cover_image_main_shortcode($attr,$content=null){
    extract(shortcode_atts(
            array(
                'title' => '',
                'image' => '',
                'image_position' => '',
                'class' => '',
                'color' => '',
                'color_density' => '',
                'theme' => 0,
                'align' => 'left',
                'max_width' => ''
            ),
            $attr,
            'cover_image_main')
    );

    //GET CLASSES
    $classesAry = array();

        //theme class
        array_push($classesAry,"theme$theme");

        //parse custom classes
        if($class!=""){
            array_push($classesAry,$class);
        }

        //Get align class
        $switchTable = array(
            'left'   => 'align-left',
            'right' => 'align-right',
            'center'    => 'align-center'
        );

        if(array_key_exists(strtolower($align), $switchTable)){
            $alignClass = $switchTable[$align];
            array_push($classesAry,$alignClass);
        }

        //create classes string
        $classes = implode(" ",$classesAry);

    //image styles
        $imageStylesAry = array();
        $imageStyles = "";

        if($image!=""){
            array_push($imageStylesAry,"background-image: url('" . $image . "')");
        }
        if($image_position!=""){
            array_push($imageStylesAry,"background-position: " . $image_position);
        }

        $imageStyles = implode(';',$imageStylesAry);

    //Get color overlay configuration
        $colorOverlayStylesAry = array();
        $colorOverlayStyles    = "";

        if($color!=""){
            array_push($colorOverlayStylesAry,"background-color: $color");
        }
        if($color_density!=""){
            if((int)$color_density < 100){
                $density = (float)$color_density/100;
                $density = number_format($density,2,'.','');
                array_push($colorOverlayStylesAry,"opacity: $density");
            }
        }

        //create color overlay styles string
        $colorOverlayStyles = implode(';',$colorOverlayStylesAry);

    //max_width declaration
    $max_width_style = "";

    if($max_width != ""){
        $max_width_style = "max-width: " . $max_width;
    }

    ob_start();
    include(SHORTCODE_TEMPLATE_FILES_URL . 'cover_image.php');
    $sc = ob_get_contents();

    ob_end_clean();

    return $sc;
}

//SHORTCODE: section_plain
//DESC:      creates a section block where content can be placed.  The section has multiple themes that can be applied
//THEMES:    default (or left blank), red, dark, gray
//ALIGN:     left, right, center
function scc_section_shortcode($attr,$content=null){
    $titleClass = "";
    extract(shortcode_atts(
            array(
                'theme'          => '0',
                'type'           => '',
                'align'          => 'left',
                'title'          => '',
                'title_style'    => 'default',
                'image'          => '',
                'image_position' => '',
                'slim'           => false,
                'text'           => '',
                'margin'         => '',
                'content_size'           => 'full'
            ),
            $attr,
            'scc_section_plain')
    );
//TODO: add in ability to supply custom section background color.  The text will need to adapt accordingly, light or dark.
    //Determine title style
    $type = strtolower($type);

    if($title_style=="uppercase"){
        $titleClass = "section-title-uppercase";
    }

//SET UP CLASSES
    $classesAry = array();

    array_push($classesAry,getThemeClass($theme)); //theme
    array_push($classesAry,getAlignClass($align)); //align class

    if($image!="" && $text=="normal"){
        array_push($classesAry,'text-normal');
    }

    if($slim!=false){
        array_push($classesAry,"section-slim");
        array_push($classesAry,"collapsed");
    }

	//Content size
	$contentSizes = array(
		'small' => 'width-small',
		'medium' => 'width-medium',
		'large' => 'width-large',
		'half' => 'width-half',
		'full' => 'width-full',
		'10' => 'width-10',
		'10%' => 'width-10',
		'20' => 'width-20',
		'20%' => 'width-20',
		'30' => 'width-30',
		'30%' => 'width-30',
		'40' => 'width-40',
		'40%' => 'width-40',
		'50' => 'width-50',
		'50%' => 'width-50',
		'60' => 'width-60',
		'60%' => 'width-60',
		'70' => 'width-70',
		'70%' => 'width-70',
		'80' => 'width-80',
		'80%' => 'width-80',
		'90' => 'width-90',
		'90%' => 'width-90',
		'100' => 'width-100',
		'100%' => 'width-100',
	);

	if(array_key_exists(strtolower($content_size),$contentSizes)){
		array_push($classesAry,$contentSizes[strtolower($content_size)]);
	}

    $classes = implode(" ",$classesAry);

//SET UP STYLES
    $stylesAry = array();

    if($image != ""){
        array_push($stylesAry,"background-image: url('$image')");
    }

    if($image_position!=""){
        array_push($stylesAry,"background-position: $image_position");
    }

    if($margin!=""){
        array_push($stylesAry,"margin: " . $margin);
    }

    $styles = implode("; ",$stylesAry);

    ob_start();

    if($type=="image" || $image != ""){
        include(SHORTCODE_TEMPLATE_FILES_URL . 'section-image.php');
    }else{
        include(SHORTCODE_TEMPLATE_FILES_URL . 'section-plain.php');
    }

    $sc = ob_get_contents();

    ob_end_clean();

    return $sc;
}
?>