<?php
/**
 * The template for displaying Services post type single posts and attachments
 *
 * @package WordPress
 * @subpackage drbollen-2020
 * @since Dr. Bollen 2020 v1.2020.1
 */

include_once(LIB_ROOT . '/vendor/mexitek-phpColors.php');
use Mexitek\PHPColors\Color;

get_header();
$page_options = scc_get_page_options();
?>
    <div id="primary" class="content-area">
        <div id="content" class="site-content" role="main">
            <div id="post" class="service__single">
                <?php
                // Start the loop.
                while ( have_posts() ) : the_post();

                    /*
                     * Include the post format-specific template for the content. If you want to
                     * use this in a child theme, then include a file called called content-___.php
                     * (where ___ is the post format) and that will be used instead.
                     */
                    $id = $post->ID;

                    $customFields = get_post_custom($id);

                    $image = wp_get_attachment_image_src( get_post_thumbnail_id($id), 'full' );
                    $image = $image['0'];

                    $content = apply_filters('the_content',get_the_content());

                    $service = array(
                        "id"                => $id,
                        "name"              => get_the_title(),
                        "content"           => $content,
                        "excerpt"           => get_the_excerpt(),
                        "short_description" => isset($customFields['short_description']) ? $customFields['short_description'][0] : '',
                        "icon"              => $customFields['service_icon'][0],
                        "color"              => $customFields['service_color'][0],
                        "background_light"  => "#ececec",
                        "image"             => $image
                    );

	                // Set a light background color based on the service color theme
	                if( isset($service['color']) && strlen($service['color'])>6 ){
		                $serviceColor = new Color(strval($service['color']));
		                $serviceColor->__set('light',.96);
		                $service['background_light'] = "#" . $serviceColor->getHex();
	                }

                    ?>

                    <div class="cover-image--pageTop" style="background-image: url('<?php echo $service['image'];?>'); background-position: center center">
                        <div class="cover-image__color-overlay" style="background-color: <?php echo $service['color'];?>; opacity: 0.35"></div>
                        <div class="wrapper">
                            <div class="cover-image_textCont">
                                <div class="cover-image_textCont--width">
                                    <div class="clearFix"></div>
                                    <?php if($service['icon'] != ""): ?><img class="service-icon" src="<?php echo $service['icon'];?>" alt="Sound Corrections <?php echo $service['name'];?> Service" style="background-color: <?php echo $service['color'];?>"><?php endif; ?>
                                    <div class="service__single--headerText">
                                        <div class="dual-title--top">Services</div>
                                        <h1 class="dual-title--bottom"><?php echo $service['name'];?></h1>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                <div class="section-custom-theme" style="background: <?php echo $service['color'];?>">
                    <?php if(isset($page_options['layout']) && $page_options['layout']=="default"): ?>
                        <section class="section-plain theme0 section-left">
                            <div class="wrapper padding-default">
                                <div class="section-content">
                    <?php endif;
                    echo $service['content'];
                    if(isset($page_options['layout']) && $page_options['layout']=="default"): ?>
                                </div>
                            </div>
                        </section>
                    <?php endif;?>
                    <section class="section-plain theme4" style="background: <?php echo $service['background_light']; ?>">
                        <div class="wrapper padding-default">
                            <div class="section-content">
                                <div class="section-title" style="color: <?php echo $service['color'];?>">Other Services</div>
                                <?php echo do_shortcode('[services_small exclude="' . $service['id'] . '" external_links="yes"]'); ?>
                            </div>
                        </div>
                    </section>
                </div>
                    <?php
                    // End the loop.
                endwhile;
                ?>
            </div>
        </div>
    </div>

<?php get_footer(); ?>